==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/BollingerBandsOverlayDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialOverlayDescriptionMetadata } from "./FinancialOverlayDescriptionMetadata";
import { BollingerBandsOverlayDescription } from "./BollingerBandsOverlayDescription";
/**
 * @hidden
 */
var BollingerBandsOverlayDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(BollingerBandsOverlayDescriptionMetadata, _super);
    function BollingerBandsOverlayDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    BollingerBandsOverlayDescriptionMetadata.b = function (a) {
        if (BollingerBandsOverlayDescriptionMetadata.a == null) {
            BollingerBandsOverlayDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            BollingerBandsOverlayDescriptionMetadata.c(BollingerBandsOverlayDescriptionMetadata.a);
        }
        if (a.g(BollingerBandsOverlayDescriptionMetadata.a)) {
            return;
        }
        a.s(BollingerBandsOverlayDescriptionMetadata.a);
    };
    BollingerBandsOverlayDescriptionMetadata.c = function (a) {
        FinancialOverlayDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
        a.item("Multiplier", "Number:double");
    };
    BollingerBandsOverlayDescriptionMetadata.d = function (a) {
        BollingerBandsOverlayDescriptionMetadata.b(a);
        a.u("BollingerBandsOverlay", function () { return new BollingerBandsOverlayDescription(); });
        a.t("BollingerBandsOverlay", BollingerBandsOverlayDescriptionMetadata.a);
    };
    BollingerBandsOverlayDescriptionMetadata.$t = markType(BollingerBandsOverlayDescriptionMetadata, 'BollingerBandsOverlayDescriptionMetadata');
    BollingerBandsOverlayDescriptionMetadata.a = null;
    return BollingerBandsOverlayDescriptionMetadata;
}(Base));
export { BollingerBandsOverlayDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/BollingerBandsOverlayDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialOverlayDescriptionMetadata } from "./FinancialOverlayDescriptionMetadata";
import { BollingerBandsOverlayDescription } from "./BollingerBandsOverlayDescription";
/**
 * @hidden
 */
var BollingerBandsOverlayDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(BollingerBandsOverlayDescriptionMetadata, _super);
    function BollingerBandsOverlayDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    BollingerBandsOverlayDescriptionMetadata.b = function (a) {
        if (BollingerBandsOverlayDescriptionMetadata.a == null) {
            BollingerBandsOverlayDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            BollingerBandsOverlayDescriptionMetadata.c(BollingerBandsOverlayDescriptionMetadata.a);
        }
        if (a.j(BollingerBandsOverlayDescriptionMetadata.a)) {
            return;
        }
        a.y(BollingerBandsOverlayDescriptionMetadata.a);
    };
    BollingerBandsOverlayDescriptionMetadata.c = function (a) {
        FinancialOverlayDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
        a.item("Multiplier", "Number:double");
    };
    BollingerBandsOverlayDescriptionMetadata.d = function (a) {
        BollingerBandsOverlayDescriptionMetadata.b(a);
        a.aa("BollingerBandsOverlay", function () { return new BollingerBandsOverlayDescription(); });
        a.z("BollingerBandsOverlay", BollingerBandsOverlayDescriptionMetadata.a);
    };
    BollingerBandsOverlayDescriptionMetadata.$t = markType(BollingerBandsOverlayDescriptionMetadata, 'BollingerBandsOverlayDescriptionMetadata');
    BollingerBandsOverlayDescriptionMetadata.a = null;
    return BollingerBandsOverlayDescriptionMetadata;
}(Base));
export { BollingerBandsOverlayDescriptionMetadata };
